@@ -17,7 +17,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '2.3.1'
+    return '2.3.1.1'
 
 
 def f_debug():
@@ -349,8 +349,11 @@ def f_debug():
 
 
         elif b[0] in ["version", "VERSION", "V", "v"]:
-            from Fishconsole import Fishconsole_version_a
-            Fishconsole_version_a.启动()
+            def start():
+                from Fishconsole import Fishconsole_version_a
+                Fishconsole_version_a.启动()
+            res=threading.Thread(target=start,daemon=True)
+            res.start()
 
 
 
